%define less_p_vers 2.11

Summary:	A text file browser similar to more, but better
Name:		less
Version:	661
Release:	%mkrel 1
License:	GPLv3+ or BSD-like
Url:		https://www.greenwoodsoftware.com/less
Group:		File tools
#Source0:	https://www.greenwoodsoftware.com/less/%%{name}-%%{version}.tar.gz
Source0:	https://github.com/gwsw/less/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:	faq_less.html
Source2:	https://www-zeuthen.desy.de/~friebel/unix/less/lesspipe-%{less_p_vers}.tar.gz
Patch0:		less-374-manpages.patch
Patch2:		lesspipe-2.11-posix.patch
Patch3:		less-382-fixline.patch
BuildRequires:	pkgconfig(ncursesw)
BuildRequires:	pkgconfig(bash-completion)
BuildRequires:	groff-for-man
BuildRequires:	zsh
# lesspipe.sh requires file
Requires:	file
Recommends:	html2text

%description
The less utility is a text file browser that resembles more, but has
more capabilities.  Less allows you to move backwards in the file as
well as forwards.  Since less doesn't have to read the entire input file
before it starts, less starts up more quickly than text editors (for
example, vi).

You should install less because it is a basic utility for viewing text
files, and you'll use it frequently.

%prep
%autosetup -p1 -a 2

chmod a+r lesspipe-%less_p_vers/*
cp -a lesspipe-%less_p_vers/README.md README.md.lesspipe

# Fix bash-completion directory
sed -i 's|/share/bash-completion|/share/bash-completion.d/completions|g' \
       lesspipe-%less_p_vers/configure

%build
CFLAGS=$(echo "%{optflags} -DHAVE_LOCALE" | sed -e s/-fomit-frame-pointer//)
autoreconf -vfi
%configure
%__make -f Makefile.aut distfiles
%make_build
cd lesspipe-%less_p_vers
./configure --prefix=%{_prefix}
cd ..

%install
%make_install
# faq
install -m 644 %{SOURCE1} .
cd lesspipe-%less_p_vers
%make_install
cd ..

mkdir -p %buildroot%_sysconfdir/profile.d/
cat << EOF > %buildroot%_sysconfdir/profile.d/20less.sh
CHARSET=\$(locale charmap 2> /dev/null)
case "\$CHARSET" in
       UTF-8)
               export LESSCHARSET="\${LESSCHARSET:-utf-8}"
       ;;
       * )
               export LESSCHARSET="\${LESSCHARSET:-koi8-r}"
       ;;
esac
# Make a filter for less
export LESSOPEN="|/usr/bin/lesspipe.sh %s"
EOF

cat << EOF > %buildroot%_sysconfdir/profile.d/20less.csh
if ! ( \$?LESSCHARSET ) then
	set CHARSET=\`locale charmap\`
	if ( "\$CHARSET" == "UTF-8" ) then
		setenv LESSCHARSET utf-8
	else
		setenv LESSCHARSET koi8-r
	endif
endif
# Make a filter for less
setenv LESSOPEN "|/usr/bin/lesspipe.sh %s"
EOF

cat << EOF > README.urpmi
This version of less includes lesspipe.sh from Wolfgang Friebel
( https://www-zeuthen.desy.de/~friebel//unix/less/ ).

This enables you to view gz, bz2, lzma, zip, rpm and html files
among others with less. It works by setting the LESSOPEN 
environment variable, see the man pages for details.

If you want to disable this behavior, either use 'unset LESSOPEN' or
use an alias ( alias less='less -l' ).

less will open html files with lynx, then html2text, then cat if
none of the previous were found.
EOF

%if 0
%check
cd lesspipe-%less_p_vers
# make sure we're testing stuff with new less and not currently installed one
export PATH=$PWD/../:$PATH
make test
%endif

%files
%doc README NEWS README.md.lesspipe
%doc faq_less.html lesspipe-%less_p_vers/{ChangeLog,german.txt}
%doc README.urpmi
%{_bindir}/*
%{_sysconfdir}/profile.d/*
%{_datadir}/bash-completion.d/completions/less_completion
%{_datadir}/zsh/site-functions/_less
%{_mandir}/man1/*


%changelog
* Mon Jul 01 2024 kekepower <kekepower> 661-1.mga10
+ Revision: 2078325
- Update to version 661

* Sun May 12 2024 kekepower <kekepower> 654-1.mga10
+ Revision: 2063878
- Update to version 654

* Tue Apr 30 2024 kekepower <kekepower> 653-4.mga10
+ Revision: 2061766
- Update to version 653

* Mon Apr 15 2024 ns80 <ns80> 643-4.mga10
+ Revision: 2057735
- add a patch from Arch Linux for CVE-2024-32487 (mga#33102)

* Fri Apr 05 2024 wally <wally> 643-3.mga10
+ Revision: 2054634
- basesystem rebuild for i686

* Mon Feb 12 2024 daviddavid <daviddavid> 643-2.mga10
+ Revision: 2040506
- update lesspipe to latest 2.11
- fix bash-completion directory (mga#32836, thanks to Aurelian R)

* Wed Sep 20 2023 daviddavid <daviddavid> 643-1.mga10
+ Revision: 1988278
- new version: 643

* Mon May 01 2023 kekepower <kekepower> 632-1.mga9
+ Revision: 1955584
- Update to latest beta version 632

* Fri Mar 24 2023 kekepower <kekepower> 629-1.mga9
+ Revision: 1950305
- Update to latest official beta version 629

* Sun Feb 05 2023 kekepower <kekepower> 623-1.mga9
+ Revision: 1938627
- Fix installation and file list
- Update to version 623 from GitHub
  o Fixes mga#31512
- Update lesspipe to version 2.07

* Sat Sep 03 2022 kekepower <kekepower> 608-1.mga9
+ Revision: 1883617
- Update to version 608
- Update lesspipe to version 2.05
- Update patches 2 and 3

* Fri Mar 18 2022 umeabot <umeabot> 590-3.mga9
+ Revision: 1797612
- Mageia 9 Mass Rebuild

* Sun Oct 10 2021 wally <wally> 590-2.mga9
+ Revision: 1750505
- update lesspipe to 1.87

* Mon Jul 12 2021 kekepower <kekepower> 590-1.mga9
+ Revision: 1735700
- Update to version 590

* Wed Apr 28 2021 kekepower <kekepower> 581.2-1.mga9
+ Revision: 1720335
- Update to version 581.2 and lesspipe 1.85

* Mon Apr 19 2021 kekepower <kekepower> 581-1.mga9
+ Revision: 1717015
- Update to version 581

* Tue Mar 02 2021 daviddavid <daviddavid> 575-1.mga9
+ Revision: 1696238
- new version: 575

* Thu Oct 22 2020 kekepower <kekepower> 563-1.mga8
+ Revision: 1638365
- Update to version 563

* Tue May 12 2020 daviddavid <daviddavid> 561-1.mga8
+ Revision: 1583339
- new version: 561

* Mon Mar 30 2020 daviddavid <daviddavid> 557-1.mga8
+ Revision: 1562265
- new version: 557

* Tue Feb 18 2020 umeabot <umeabot> 551-2.mga8
+ Revision: 1541791
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Jan 02 2020 luigiwalser <luigiwalser> 551-1.mga8
+ Revision: 1475411
- 551

* Tue Feb 19 2019 wally <wally> 550-1.mga7
+ Revision: 1368505
- new version 550

* Sun Feb 17 2019 luigiwalser <luigiwalser> 549-1.mga7
+ Revision: 1367967
- 549

* Sat Dec 29 2018 luigiwalser <luigiwalser> 548-1.mga7
+ Revision: 1345917
- 548

* Sun Aug 26 2018 daviddavid <daviddavid> 533-1.mga7
+ Revision: 1254811
- new version: 533

* Sun Feb 18 2018 kekepower <kekepower> 530-1.mga7
+ Revision: 1202776
- Update to version 530
- Remove patch that has been merged upstream

* Wed Sep 06 2017 joequant <joequant> 487-2.mga7
+ Revision: 1151687
- rebuild with new gcc

* Thu Mar 30 2017 luigiwalser <luigiwalser> 487-1.mga6
+ Revision: 1095290
- 487
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 02 2015 luigiwalser <luigiwalser> 481-1.mga6
+ Revision: 907738
- 481
- lesspipe 1.83
- use Foption patch from fedora

* Fri Aug 21 2015 tmb <tmb> 458-6.mga6
+ Revision: 867529
- rebuild for new gcc

* Wed Mar 25 2015 luigiwalser <luigiwalser> 458-5.mga5
+ Revision: 819255
- add patch from opensuse to fix CVE-2014-9488

* Wed Oct 15 2014 umeabot <umeabot> 458-4.mga5
+ Revision: 745926
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 458-3.mga5
+ Revision: 681300
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Sat Oct 19 2013 umeabot <umeabot> 458-2.mga4
+ Revision: 523931
- Mageia 4 Mass Rebuild

* Sun May 26 2013 blino <blino> 458-1.mga4
+ Revision: 428315
- less 458 & lesspipe 1.82

* Sat Jan 12 2013 umeabot <umeabot> 451-2.mga3
+ Revision: 356752
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Sep 20 2012 tv <tv> 451-1.mga3
+ Revision: 296277
- new release
- drop useless macros
- rediff patch

* Sun Jul 01 2012 luigiwalser <luigiwalser> 449-1.mga3
+ Revision: 266267
- 449
+ colin <colin>
- Update to latest fedora patch regarding the -F (quit if one screen)
- Fix the -F option to properly count lines before deciding to disable init options.

* Sat Jan 28 2012 tv <tv> 445-1.mga2
+ Revision: 202500
- new release

* Wed Jul 13 2011 ahmad <ahmad> 444-1.mga2
+ Revision: 123678
- Update to 444
- Update lesspipe to 1.71
- Rediff patch2 (posix)
- Drop patch5, fixed differently upstream
- Disable the lesspipe tests, (e.g. one of them requires unrar)
+ tmb <tmb>
- imported package less

